From 4b9d5cd35252bf022b0898c6a96823cfef92185d Mon Sep 17 00:00:00 2001
From: Richard Wackerbarth <rkw@dataplex.net>
Date: Fri, 31 Jul 2015 22:31:53 -0500
Subject: [PATCH] Use lowercase names for serial instances

---
 Marlin/Marlin.h         | 4 ++--
 Marlin/MarlinSerial.cpp | 4 ++--
 Marlin/MarlinSerial.h   | 6 +++---
 Marlin/pins_TEENSYLU.h  | 2 +-
 Marlin/stepper.cpp      | 2 +-
 5 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/Marlin/Marlin.h b/Marlin/Marlin.h
index fad838e934..88fa740319 100644
--- a/Marlin/Marlin.h
+++ b/Marlin/Marlin.h
@@ -52,12 +52,12 @@ typedef unsigned long millis_t;
 
 #ifdef USBCON
   #if ENABLED(BLUETOOTH)
-    #define MYSERIAL bt
+    #define MYSERIAL bluetoothSerial
   #else
     #define MYSERIAL Serial
   #endif // BLUETOOTH
 #else
-  #define MYSERIAL MSerial
+  #define MYSERIAL customizedSerial
 #endif
 
 #define SERIAL_CHAR(x) MYSERIAL.write(x)
diff --git a/Marlin/MarlinSerial.cpp b/Marlin/MarlinSerial.cpp
index bd7314b245..5d3894455d 100644
--- a/Marlin/MarlinSerial.cpp
+++ b/Marlin/MarlinSerial.cpp
@@ -281,12 +281,12 @@ void MarlinSerial::printFloat(double number, uint8_t digits) {
 // Preinstantiate Objects //////////////////////////////////////////////////////
 
 
-MarlinSerial MSerial;
+MarlinSerial customizedSerial;
 
 #endif // whole file
 #endif // !USBCON
 
 // For AT90USB targets use the UART for BT interfacing
 #if defined(USBCON) && ENABLED(BLUETOOTH)
-  HardwareSerial bt;
+  HardwareSerial bluetoothSerial;
 #endif
diff --git a/Marlin/pins_TEENSYLU.h b/Marlin/pins_TEENSYLU.h
index 293da35dbd..c21693da7f 100644
--- a/Marlin/pins_TEENSYLU.h
+++ b/Marlin/pins_TEENSYLU.h
@@ -74,7 +74,7 @@
   #if ENABLED(LCD_I2C_PANELOLU2)
     #define BTN_EN1        27  //RX1 - fastio.h pin mapping 27
     #define BTN_EN2        26  //TX1 - fastio.h pin mapping 26
-    #define BTN_ENC        43  //A3 - fastio.h pin mapping 43
+    #define BTN_ENC        43  //A3  - fastio.h pin mapping 43
     #define SDSS           40  //use SD card on Panelolu2 (Teensyduino pin mapping)
   #endif // LCD_I2C_PANELOLU2
 
diff --git a/Marlin/stepper.cpp b/Marlin/stepper.cpp
index 2dd2f477c1..80f1bb272f 100644
--- a/Marlin/stepper.cpp
+++ b/Marlin/stepper.cpp
@@ -655,7 +655,7 @@ ISR(TIMER1_COMPA_vect) {
     // Take multiple steps per interrupt (For high speed moves)
     for (int8_t i = 0; i < step_loops; i++) {
       #ifndef USBCON
-        MSerial.checkRx(); // Check for serial chars.
+        customizedSerial.checkRx(); // Check for serial chars.
       #endif
 
       #if ENABLED(ADVANCE)
diff --git a/Marlin/MarlinSerial.h b/Marlin/MarlinSerial.h
index bd1e447268..b7424cf453 100644
--- a/Marlin/MarlinSerial.h
+++ b/Marlin/MarlinSerial.h
@@ -149,12 +149,12 @@ class MarlinSerial { //: public Stream
     void println(void);
 };
 
-extern MarlinSerial MSerial;
+extern MarlinSerial customizedSerial;
 #endif // !USBCON
 
 // Use the UART for BT in AT90USB configurations
 #if defined(USBCON) && ENABLED(BLUETOOTH)
-  extern HardwareSerial bt;
+  extern HardwareSerial bluetoothSerial;
 #endif
 
 #endif
@@ -149,12 +149,12 @@ class MarlinSerial { //: public Stream
 #endif // !USBCON
 
-// Use the UART for BT in AT90USB configurations
+// Use the UART for Bluetooth in AT90USB configurations
 #if defined(USBCON) && ENABLED(BLUETOOTH)